@@ -9,20 +9,26 @@
 #' @examples
 #' \donttest{
 #' library(MeasurementDiagnostics)
+#'
 #' cdm <- mockMeasurementDiagnostics()
+#'
 #' result <- summariseMeasurementUse(
-#'               cdm = cdm,
-#'               bySex = TRUE,
-#'               codes = list("test_codelist" = c(3001467L, 45875977L)))
-#' plotMeasurementValueAsNumeric(result)
+#'   cdm = cdm,
+#'   bySex = TRUE,
+#'   codes = list("test_codelist" = c(3001467L, 45875977L))
+#' )
+#'
+#' plotMeasurementValueAsNumber(result)
+#'
 #' CDMConnector::cdmDisconnect(cdm)
 #' }
-plotMeasurementValueAsNumeric <- function(result,
-                                          x = c("unit_concept_name"),
-                                          plotType = "boxplot",
-                                          facet = c("codelist_name", "concept_name"),
-                                          colour = c("cdm_name", "unit_concept_name", visOmopResults::strataColumns(result))) {
-  omopgenerics::assertChoice(plotType, c("boxplot", "densityplot"), length = 1)
+plotMeasurementValueAsNumber <- function(result,
+                                         x = "unit_concept_name",
+                                         plotType = "boxplot",
+                                         facet = c("codelist_name", "concept_name"),
+                                         colour = c("cdm_name", "unit_concept_name", visOmopResults::strataColumns(result)),
+                                         style = NULL) {
+  omopgenerics::assertChoice(plotType, c("boxplot", "densityplot", "barplot"), length = 1)
   result <- omopgenerics::validateResultArgument(result)
   rlang::check_installed("visOmopResults")
 
@@ -33,10 +39,10 @@ plotMeasurementValueAsNumeric <- function(result,
   colour <- intersect(colour, plotCols)
 
   result <- result |>
-    omopgenerics::filterSettings(.data$result_type == "measurement_value_as_numeric")
+    omopgenerics::filterSettings(.data$result_type == "measurement_value_as_number")
 
   if (nrow(result) == 0) {
-    cli::cli_warn("There are no results with `result_type = measurement_value_as_numeric`")
+    cli::cli_warn("There are no results with `result_type = measurement_value_as_number`")
     return(visOmopResults::emptyPlot())
   }
 
@@ -47,13 +53,16 @@ plotMeasurementValueAsNumeric <- function(result,
   } else if (plotType == "densityplot"){
     result <- result |>
       dplyr::filter(grepl("density", .data$estimate_name))
+  } else if (plotType == "barplot"){
+    result <- result |>
+      dplyr::filter(.data$estimate_name == "count" & .data$variable_name == "value_as_number")
   }
 
   # Remove overall option when byConcept is TRUE
-  if("codelist_name &&& concept_name" %in% result$group_name){
+  if("codelist_name &&& concept_name &&& source_concept_name" %in% result$group_name){
     result <- result |>
-      dplyr::filter(.data$group_name %in% c("codelist_name &&& concept_name &&& unit_concept_name",
-                                            "codelist_name &&& concept_name"))
+      dplyr::filter(.data$group_name %in% c("codelist_name &&& concept_name &&& source_concept_name &&& unit_concept_name",
+                                            "codelist_name &&& concept_name &&& source_concept_name"))
   }
 
   if(length(result |> dplyr::pull("estimate_value") |> unique()) == 1 && is.na((result |> dplyr::pull("estimate_value") |> unique()))){
@@ -76,6 +85,7 @@ plotMeasurementValueAsNumeric <- function(result,
       label = visOmopResults::plotColumns(result)
     ) +
       ggplot2::xlab(label = paste0(xLab, collapse = ", and "))
+
   } else if (plotType == "densityplot") {
     p <- visOmopResults::scatterPlot(
       result = result,
@@ -90,6 +100,19 @@ plotMeasurementValueAsNumeric <- function(result,
       colour = colour,
       label = visOmopResults::plotColumns(result)
     )
+
+  } else if (plotType == "barplot") {
+    p <- result |>
+      visOmopResults::barPlot(
+        x = x,
+        y = "count",
+        just = 0.5,
+        position = "dodge",
+        facet = facet,
+        colour = colour,
+        style = style,
+        label = visOmopResults::plotColumns(result)
+      )
   }
   p +
     ggplot2::ylab(label = "Measurement numeric value") +
