@@ -1,4 +1,4 @@
-#' Format a measurement_timings object into a visual table
+#' Format a measurement_summary object into a visual table
 #'
 #' @inheritParams resultDoc
 #' @inheritParams tableDoc
@@ -10,33 +10,38 @@
 #' @examples
 #' \donttest{
 #' library(MeasurementDiagnostics)
+#'
 #' cdm <- mockMeasurementDiagnostics()
+#'
 #' result <- summariseMeasurementUse(
-#'               cdm = cdm,
-#'               codes = list("test_codelist" = c(3001467L, 45875977L)))
-#' tableMeasurementValueAsNumeric(result)
+#'   cdm = cdm,
+#'   codes = list("test_codelist" = c(3001467L, 45875977L))
+#' )
+#'
+#' tableMeasurementValueAsNumber(result)
+#'
 #' CDMConnector::cdmDisconnect(cdm = cdm)
 #'}
-tableMeasurementValueAsNumeric <- function(result,
-                                           type = "gt",
-                                           header = c(visOmopResults::strataColumns(result)),
-                                           groupColumn = c("codelist_name"),
-                                           settingsColumn = character(),
-                                           hide = c("variable_name", "variable_level"),
-                                           style = "default",
-                                           .options = list()){
+tableMeasurementValueAsNumber <- function(result,
+                                          header = c(visOmopResults::strataColumns(result)),
+                                          groupColumn = c("codelist_name"),
+                                          settingsColumn = character(),
+                                          hide = c("variable_name", "variable_level"),
+                                          style = NULL,
+                                          type = NULL,
+                                          .options = list()){
   rlang::check_installed("visOmopResults")
 
   # check inputs
-  result <- omopgenerics::validateResultArgument(result, call = call)
+  result <- omopgenerics::validateResultArgument(result)
 
   # subset to rows of interest
   result <- result |>
-    omopgenerics::filterSettings(.data$result_type == "measurement_value_as_numeric") |>
+    omopgenerics::filterSettings(.data$result_type == "measurement_value_as_number") |>
     dplyr::filter(!grepl("density", .data$estimate_name))
 
   if (nrow(result) == 0) {
-    cli::cli_warn("There are no results with `result_type = measurement_value_as_numeric`")
+    cli::cli_warn("There are no results with `result_type = measurement_value_as_number`")
     return(visOmopResults::emptyTable(type = type))
   }
 
@@ -44,8 +49,9 @@ tableMeasurementValueAsNumeric <- function(result,
 
   columnOrder <- c(
     "cdm_name", "cohort_name", "codelist_name", "concept_name", "concept_id",
-    "domain_id", "unit_concept_name", "unit_concept_id", "sex", "age_group",
-    "year", settingsColumn, "variable_name", "variable_level", "estimate_name",
+    "source_concept_name", "source_concept_id", "domain_id",
+    "unit_concept_name", "unit_concept_id", "sex", "age_group", "year",
+    settingsColumn, "variable_name", "variable_level", "estimate_name",
     "estimate_value"
   )
   # temp fix for visOmpReuslts issue 355
@@ -79,7 +85,13 @@ tableMeasurementValueAsNumeric <- function(result,
       header = header,
       settingsColumn = settingsColumn,
       groupColumn = groupColumn,
-      rename = c("CDM name" = "cdm_name", "Concept ID" = "concept_id", "Unit concept ID" = "unit_concept_id", "Domain ID" = "domain_id"),
+      rename = c(
+        "CDM name" = "cdm_name",
+        "Concept ID" = "concept_id",
+        "Source concept ID" = "source_concept_id",
+        "Unit concept ID" = "unit_concept_id",
+        "Domain ID" = "domain_id"
+      ),
       type = type,
       hide = hide,
       columnOrder = columnOrder,
